flux_form library
Flux Form — modular, type-safe, state-management-agnostic form library.
Classes
-
AsyncValidator<
T, E> - An asynchronous validation rule.
-
BoolInput<
E> -
BoolInputBuilder<
E> - A fluent builder that composes validators into a SimpleBoolInput.
-
BoolValidator<
E> - A namespace for Boolean rules.
-
ComparableValidator<
T extends Comparable< T> , E> - A namespace for Comparable validation rules (dates, durations, numbers).
-
DateTimeInput<
E> -
DateTimeInputBuilder<
E> - A fluent builder that composes validators into a SimpleDateTimeInput.
-
ExternalValidator<
T, E> - A namespace for adapting external validation libraries (like form_builder_validators) into Flux Form validators.
-
FileValidator<
E> - A namespace for File validation rules.
-
FormatValidator<
E> - FormError
- Interface for form errors.
-
FormInput<
T, E> - FormSchema
- A base class for strongly-typed, aggregate form schemas.
-
FormSubmitter<
T> - A utility class to encapsulate and standardise form submission lifecycles.
- FormValidator
-
InputData<
T, E> - Data class for storing input state.
-
ListInput<
T, E> -
ListInputBuilder<
T, E> - A fluent builder that composes list-level and item-level validators and sanitizers into a concrete ListInput<T, E>.
-
ListSanitizer<
T> - A namespace for List transformation rules.
-
ListValidator<
T, E> - A namespace for List/Array validation rules.
-
LogicValidator<
T, E> - A convenience entry point for Logic Validators.
-
MapInput<
K, V, E> -
MapInputBuilder<
K, V, E> - A fluent builder that composes map-level and value-level validators and sanitizers into a SimpleMapInput<K, V, E>.
-
MapValidator<
K, V, E> - A namespace for Map-level validation rules.
- MultiStepSchema
- A concrete, immutable wrapper that models a multi-step form (wizard).
-
NumberInput<
T extends num, E> -
NumberInputBuilder<
T extends num, E> - A fluent builder that composes validators and sanitizers into a SimpleNumberInput<T, E>.
- NumberSanitizer
- A namespace for Number transformation rules.
-
NumberValidator<
E> - A namespace for Numeric validation rules (int/double).
-
ObjectInput<
T, E extends FormError> -
ObjectValidator<
T, E> - A namespace for generic object matching rules.
-
Sanitizer<
T> - Interface for transforming / cleaning data before validation.
- SanitizerPipeline
- Helper to run a list of sanitizers.
-
SchemaValidator<
E> - A validation rule that operates on an entire FormSchema rather than a single input.
-
SimpleBoolInput<
E> -
SimpleDateTimeInput<
E> -
SimpleListInput<
T, E> -
SimpleMapInput<
K, V, E> -
SimpleNumberInput<
T extends num, E> -
SimpleObjectInput<
T, E extends FormError> -
SimpleStringInput<
E> -
StringInput<
E> -
StringInputBuilder<
E> - A fluent builder that composes validators, sanitizers, and mode into a SimpleStringInput without requiring a subclass.
- StringSanitizer
- A namespace for String transformation rules.
-
StringValidator<
E> - A namespace for String-based validation rules.
-
Validator<
T, E> - A synchronous validation rule.
- ValidatorPipeline
- Helper that runs lists of Validator and AsyncValidator instances.
Enums
- InputStatus
- Enum for tracking the interaction state of a form field.
- SubmissionStatus
- Represents the current state of a form submission.
- ValidationMode
- Controls when a field's validation error becomes visible in the UI.
Mixins
- FormMixin
- A mixin for State classes that manage inputs individually, rather than through a FormSchema.
-
InputMixin<
T, E, I extends FormInput< T, E> > - A mixin that provides fluent convenience methods for FormInput subclasses.
Typedefs
-
ExternalValidationRule<
T> = String? Function(T? value) - A standard Flutter validation signature used by most packages.
-
OnValidateError<
T, E> = void Function(T value, E error) -
OnValidateStart<
T> = void Function(T value) -
OnValidateSuccess<
T> = void Function(T value) -
StandardInput<
T, E extends FormError> = SimpleObjectInput< T, E> - Backwards-compatibility alias for ObjectInput.
- ValidatorPredicate = bool Function()